"""Celery tasks API for CIC EVM and web3 JSON-RPC interactions

.. moduleauthor: Louis Holbrook <dev@holbrook.no>

"""

from .api_task import Api
from .api_admin import AdminApi
